summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorbart@po8.org <bart@po8.org>2006-09-12 01:00:13 -0700
committerKeith Packard <keithp@neko.keithp.com>2006-09-12 09:12:04 -0700
commit47be0f00a21fa2053d600c49707335825182b4bd (patch)
tree919e3ad029e5bee1285733de27b075510993fe55
parentabc5f38e445c8124b8febff40ade151fd274fe94 (diff)
[PATCH] More compilation fixes
I'm not sure the attached fix is at all correct, but it at least makes vague sense and got the nsc driver to compile. I'm stuck right now with a missing source symbol (SMI_COUGAR3DR) in the Silicon Motion driver. I'm giving up and going to sleep; I'll bug you tomorrow. Bart Signed-off-by: Keith Packard <keithp@neko.keithp.com>
-rw-r--r--src/panel/platform.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/panel/platform.c b/src/panel/platform.c
index f8eb67f..94707c1 100644
--- a/src/panel/platform.c
+++ b/src/panel/platform.c
@@ -193,8 +193,8 @@ static unsigned char get_sys_board_type(SYS_BOARD_INFO *, SYS_BOARD_INFO *);
#if defined(linux) && !defined(__KERNEL__)
#if !defined(XFree86Server)
-static void protected_mode_access(unsigned int, unsigned int,
- unsigned long, unsigned char *);
+static void platform_protected_mode_access(unsigned int, unsigned int,
+ unsigned long, unsigned char *);
static void setup_pma();
static void close_pma();
static int fd;
@@ -310,7 +310,7 @@ FindStringInSeg(unsigned int segment_address, char *string_ptr)
/* Fill the segment_buffer with 16 page accesses */
for (cursor = 0; (cursor * PAGE_LENGTH) < SEGMENT_LENGTH; cursor++) {
- protected_mode_access(PLT_READ_BYTES, PAGE_LENGTH, mem_ptr +
+ platform_protected_mode_access(PLT_READ_BYTES, PAGE_LENGTH, mem_ptr +
(cursor * PAGE_LENGTH),
&(segment_buffer[(cursor * PAGE_LENGTH)]));
}
@@ -403,7 +403,7 @@ get_sys_board_type(SYS_BOARD_INFO * sys_info,
/******************************************************************
*
* protected_mode_access( unsigned int mode, unsigned int width,
* unsigned long addr, unsigned char* pdata )
* This function provides access to physical memory
* at the requested address.
@@ -428,7 +428,7 @@ get_sys_board_type(SYS_BOARD_INFO * sys_info,
*/
static void
-protected_mode_access(unsigned int mode, unsigned int width,
+platform_protected_mode_access(unsigned int mode, unsigned int width,
unsigned long addr, unsigned char *pdata)
{
@@ -403,7 +403,7 @@ get_sys_board_type(SYS_BOARD_INFO * sys_info,
/******************************************************************
*
- * protected_mode_access( unsigned int mode, unsigned int width,
+ * platform_protected_mode_access( unsigned int mode, unsigned int width,
* unsigned long addr, unsigned char* pdata )
* This function provides access to physical memory